@@ -1,13 +1,25 @@
-#' Get edge attribute values
-#' @description From a graph object of class
-#' \code{dgr_graph}, get edge attribute values for one
+#' Get edge attribute values from a selection of edges
+#'
+#' From a graph object of class `dgr_graph`, get edge attribute values for one
 #' or more edges.
-#' @param graph a graph object of class
-#' \code{dgr_graph}.
-#' @param edge_attr the name of the attribute for which
-#' to get values.
-#' @return a named vector of edge attribute values for
-#' the attribute given by \code{edge_attr} by edge.
+#'
+#' This function makes use of an active selection of edges (and the function
+#' ending with `_ws` hints at this).
+#'
+#' Selections of edges can be performed using the following selection
+#' (`select_*()`) functions: [select_edges()], [select_last_edges_created()],
+#' [select_edges_by_edge_id()], or [select_edges_by_node_id()].
+#'
+#' Selections of edges can also be performed using the following traversal
+#' (`trav_*()`) functions: [trav_out_edge()], [trav_in_edge()],
+#' [trav_both_edge()], or [trav_reverse_edge()].
+#'
+#' @inheritParams render_graph
+#' @param edge_attr the name of the attribute for which to get values.
+#'
+#' @return A named vector of edge attribute values for the attribute given by
+#'   `edge_attr` by edge.
+#'
 #' @examples
 #' # Create a simple graph where
 #' # edges have an edge attribute
@@ -60,10 +72,9 @@
 #' graph %>%
 #'   get_edge_attrs_ws(
 #'     edge_attr = value)
-#' @importFrom dplyr filter pull
-#' @importFrom rlang enquo UQ get_expr
-#' @export get_edge_attrs_ws
-
+#'
+#' @import rlang
+#' @export
 get_edge_attrs_ws <- function(graph,
                               edge_attr) {
 
@@ -88,9 +99,6 @@ get_edge_attrs_ws <- function(graph,
 
   edge_attr <- rlang::enquo(edge_attr)
 
-  # Create binding for a specific variable
-  id <- NULL
-
   if (rlang::enquo(edge_attr) %>%
       rlang::get_expr() %>%
       as.character() %in% c("id", "from", "to")) {
@@ -114,13 +122,10 @@ get_edge_attrs_ws <- function(graph,
     dplyr::filter(id %in% edges)
 
   # Extract the edge attribute values
-  edge_attr_vals <-
-    edf %>%
-    dplyr::pull(rlang::UQ(edge_attr))
+  edge_attr_vals <- edf %>% dplyr::pull(!!edge_attr)
 
   # Extract the edge names
-  edge_names <-
-    paste(edf$from, edf$to, sep = "->")
+  edge_names <- paste(edf$from, edf$to, sep = "->")
 
   # Assign edge names
   names(edge_attr_vals) <- edge_names
