@@ -1,32 +1,33 @@
-#' Select nodes based on a walk distance from a
-#' specified node
-#' @description Select those nodes in the neighborhood
-#' of nodes connected a specified distance from an
-#' initial node.
-#' @param graph a graph object of class
-#' \code{dgr_graph}.
-#' @param node the node from which the traversal
-#' will originate.
-#' @param distance the maximum number of steps from
-#' the \code{node} for inclusion in the selection.
-#' @param set_op the set operation to perform upon
-#' consecutive selections of graph nodes. This can
-#' either be as a \code{union} (the default), as an
-#' intersection of selections with \code{intersect},
-#' or, as a \code{difference} on the previous
-#' selection, if it exists.
-#' @return a graph object of class \code{dgr_graph}.
+#' Select nodes based on a walk distance from a specified node
+#'
+#' Select those nodes in the neighborhood of nodes connected a specified
+#' distance from an initial node.
+#'
+#' @inheritParams render_graph
+#' @param node The node from which the traversal will originate.
+#' @param distance The maximum number of steps from the `node` for inclusion in
+#'   the selection.
+#' @param set_op The set operation to perform upon consecutive selections of
+#'   graph nodes. This can either be as a `union` (the default), as an
+#'   intersection of selections with `intersect`, or, as a `difference` on the
+#'   previous selection, if it exists.
+#'
+#' @return A graph object of class `dgr_graph`.
+#'
 #' @examples
-#' # Create a graph containing a balanced tree
+#' # Create a graph containing
+#' # a balanced tree
 #' graph <-
 #'   create_graph() %>%
 #'   add_balanced_tree(
 #'     k = 2, h = 2)
 #'
-#' # Create a graph selection by selecting nodes
-#' # in the neighborhood of node `1`, where the
-#' # neighborhood is limited by nodes that are 1
-#' # connection away from node `1`
+#' # Create a graph selection by
+#' # selecting nodes in the
+#' # neighborhood of node `1`, where
+#' # the neighborhood is limited by
+#' # nodes that are 1 connection
+#' # away from node `1`
 #' graph <-
 #'   graph %>%
 #'   select_nodes_in_neighborhood(
@@ -34,12 +35,12 @@
 #'     distance = 1)
 #'
 #' # Get the selection of nodes
-#' graph %>%
-#'   get_selection()
-#' #> [1] 1 2 3
+#' graph %>% get_selection()
 #'
-#' # Perform another selection of nodes, this time
-#' # with a neighborhood spanning 2 nodes from node `1`
+#' # Perform another selection
+#' # of nodes, this time with a
+#' # neighborhood spanning 2 nodes
+#' # from node `1`
 #' graph <-
 #'   graph %>%
 #'   clear_selection() %>%
@@ -48,11 +49,9 @@
 #'     distance = 2)
 #'
 #' # Get the selection of nodes
-#' graph %>%
-#'   get_selection()
-#' #> [1] 1 2 3 4 5 6 7
-#' @export select_nodes_in_neighborhood
-
+#' graph %>% get_selection()
+#'
+#' @export
 select_nodes_in_neighborhood <- function(graph,
                                          node,
                                          distance,
@@ -61,16 +60,30 @@ select_nodes_in_neighborhood <- function(graph,
   # Get the time of function start
   time_function_start <- Sys.time()
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   # Validation: Graph contains nodes
   if (graph_contains_nodes(graph) == FALSE) {
-    stop("The graph contains no nodes, so, no selections can be made.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph contains no nodes")
   }
 
+  # Obtain the input graph's node and edge
+  # selection properties
+  n_e_select_properties_in <-
+    node_edge_selection_properties(graph = graph)
+
   # Create an empty list object
   nodes <- list()
 
@@ -151,7 +164,7 @@ select_nodes_in_neighborhood <- function(graph,
       intersect(nodes_prev_selection, nodes_selected)
   } else if (set_op == "difference") {
     nodes_combined <-
-      setdiff(nodes_prev_selection, nodes_selected)
+      base::setdiff(nodes_prev_selection, nodes_selected)
   }
 
   # Add the node ID values to the active selection
@@ -164,12 +177,17 @@ select_nodes_in_neighborhood <- function(graph,
   # Replace `graph$edge_selection` with an empty df
   graph$edge_selection <- create_empty_esdf()
 
+  # Obtain the output graph's node and edge
+  # selection properties
+  n_e_select_properties_out <-
+    node_edge_selection_properties(graph = graph)
+
   # Update the `graph_log` df with an action
   graph$graph_log <-
     add_action_to_log(
       graph_log = graph$graph_log,
       version_id = nrow(graph$graph_log) + 1,
-      function_used = "select_nodes_in_neighborhood",
+      function_used = fcn_name,
       time_modified = time_function_start,
       duration = graph_function_duration(time_function_start),
       nodes = nrow(graph$nodes_df),
@@ -180,5 +198,49 @@ select_nodes_in_neighborhood <- function(graph,
     save_graph_as_rds(graph = graph)
   }
 
+  # Emit a message about the modification of a selection
+  # if that option is set
+  if (!is.null(graph$graph_info$display_msgs) &&
+      graph$graph_info$display_msgs) {
+
+    # Construct message body
+    if (!n_e_select_properties_in[["node_selection_available"]] &
+        !n_e_select_properties_in[["edge_selection_available"]]) {
+
+      msg_body <-
+        glue::glue(
+          "created a new selection of \\
+        {n_e_select_properties_out[['selection_count_str']]}")
+
+    } else if (n_e_select_properties_in[["node_selection_available"]] |
+               n_e_select_properties_in[["edge_selection_available"]]) {
+
+      if (n_e_select_properties_in[["edge_selection_available"]]) {
+        msg_body <-
+          glue::glue(
+            "modified an existing selection of\\
+           {n_e_select_properties_in[['selection_count_str']]}:
+           * {n_e_select_properties_out[['selection_count_str']]}\\
+           are now in the active selection
+           * used the `{set_op}` set operation")
+      }
+
+      if (n_e_select_properties_in[["node_selection_available"]]) {
+        msg_body <-
+          glue::glue(
+            "created a new selection of\\
+           {n_e_select_properties_out[['selection_count_str']]}:
+           * this replaces\\
+           {n_e_select_properties_in[['selection_count_str']]}\\
+           in the prior selection")
+      }
+    }
+
+    # Issue a message to the user
+    emit_message(
+      fcn_name = fcn_name,
+      message_body = msg_body)
+  }
+
   graph
 }
